@@ -4,11 +4,12 @@
     (LaTeX-add-labels
      "fig:magma"
      "subsec:hardware"
+     "fig:lattice"
+     "fig:logloglattice"
      "tab:logloganalysis"
      "fig:slopeloglog")
     (TeX-run-style-hooks
      "booktabs"
-     "float"
      "latex2e"
      "jss10"
      "jss"
